@@ -30,7 +30,8 @@ public class Constants {
 	public static final String PARAMETER_DATA_TYPE="dataType";
 	public static final String PARAMETER_TARGET_DATA_TYPE="targetDataType";
 	
+	public static final String PARAMETER_EXPRESSION="expression";
 	
-	
+	public static final String PARAMETER_TABLE_TYPE="tableType";
 
 }
